<ul class="nav nav-pills nav-stacked c2cgeoform-item-actions">
  {% for item in actions %}
	  <li class="c2cgeoform-item-action">
	    <a class="btn btn-default" href="{{ item['url'] }}">{{item['label']}}</a>
	  </li>
  {% endfor %}
  
</ul>
