
.panel-body label, .form-group label {
  color: black;
}

.panel-body .form-control-static {
  color: black;
}
.deformClosebutton {
  margin-right: 3px;
}

.list-grid {
  color: #42325b;
}

.btn-new {
  float: left;
  margin: 15px 0;
}

.bootgrid-header {
  float: right;
}

.deformFileupload span, .deformFileupload input[type=file] {
  color: #000000;
}

.deformFileupload .deformReplaces {
  float: none;
}

.wizard > .content > .body div.ol-attribution > ul > li {
  display: inline;
  padding: 0;
}

/* Typeahead's dropdown meny */
.tt-dropdown-menu {
  color: black;
}

/*
 * Grid
 */
#grid {
  table-layout: auto;
}
.table>tbody>tr>td,
.table>tbody>tr>th,
.table>tfoot>tr>td,
.table>tfoot>tr>th,
.table>thead>tr>td,
.table>thead>tr>th {
  vertical-align: middle;
}
ul.grid-row-actions {
  padding: 0;
  margin: 0;
}
li.grid-row-action {
  display: inline-block;
  margin-right: 5px;
}
